/*
 *  Graphical Turing Machine
 *
 *  Copyright (C) 2008 by Eric Hutchins
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **/

#include "transition.h"

/*
Transition::Transition(State* begin_state, string input_symbol, 
                       string output_symbol, int movement, State* end_state)
{
  m_begin_state = begin_state;
  m_input_symbol = input_symbol;
  m_output_symbol = output_symbol;
  m_movement = movement;
  m_end_state = end_state;
}
*/

Transition::Transition(State* begin_state, vector<string> input_symbols, 
           vector<string> output_symbols, vector<int> movement, 
           State* end_state)
{
  m_begin_state = begin_state;
  m_input_symbols = input_symbols;
  m_output_symbols = output_symbols;
  m_movement = movement;
  m_end_state = end_state;
}
Transition::~Transition()
{
}

